import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState, useEffect } from 'react';
import { Button, Card, CardBody, CardHeader, Heading, Stack, Text } from '@chakra-ui/react';
import { useRecordingStatus } from '../hooks/use-recording-status.js';
import { useRecordingCycle } from '../hooks/use-recording-cycle.js';
import { useContainer } from '../hooks/use-container.js';
import { startRecording } from '../strart-recording.js';
import { stopRecording } from '../stop-recording.js';
import { downloadRecords } from '../download-records.js';
import { usePermissions } from '../hooks/use-permissions.js';
/**
 * React component for using the voice recorder.
 * @param {DeepClient} deep - The DeepClient object instance.
 */
export function VoiceRecorder({ deep, containerLinkId: passedContainerLinkId }) {
    const [recording, setRecording] = useState(false); // State variable to track recording status
    const [records, setRecords] = useState([]); // State variable to store downloaded audio files
    const containerLinkIdFromHook = useContainer(deep);
    const [containerLinkId, setContainerLinkId] = useState(passedContainerLinkId || containerLinkIdFromHook);
    useEffect(() => {
        setContainerLinkId(passedContainerLinkId || containerLinkIdFromHook);
    }, [deep, passedContainerLinkId, containerLinkIdFromHook]);
    const { recorderPermissions, deviceSupport, getPermissions, getDeviceSupport } = usePermissions(); // Custom hook to get permissions
    const audioRecordingStatus = useRecordingStatus({}); // Custom hook to get audio recording status
    const sounds = useRecordingCycle({ deep, recording, containerLinkId, duration: 5000 }); // Custom hook to fire recording cycle
    return (_jsxs(Stack, { children: [_jsxs(Card, { children: [_jsx(CardHeader, { children: _jsx(Heading, { children: "Ability to record" }) }), _jsx(CardBody, { children: _jsx(Text, { children: `Device is ${!deviceSupport ? 'not' : ''} able to record.` }) })] }), _jsxs(Card, { children: [_jsx(CardHeader, { children: _jsx(Heading, { children: "Permissions" }) }), _jsxs(CardBody, { children: [_jsx(Text, { children: `Permissions are ${!recorderPermissions ? 'not' : ''} granted.` }), _jsx(Button, { onClick: async () => await getPermissions(), children: "Request permissions" })] })] }), _jsx(Card, { children: _jsx(CardHeader, { children: _jsx(Heading, { children: `Audio Recording Status: ${audioRecordingStatus}` }) }) }), _jsx(Card, { children: _jsx(CardHeader, { children: _jsx(Heading, { children: `Container Link Id: ${containerLinkId}` }) }) }), _jsx(Button, { onClick: async () => await startRecording(), children: "START RECORDING" }), _jsx(Button, { onClick: async () => await stopRecording({ deep, containerLinkId }), children: "STOP RECORDING" }), _jsx(Button, { onClick: () => setRecording(true), children: "START RECORDING CYCLE" }), _jsx(Button, { onClick: () => setRecording(false), children: "STOP RECORDING CYCLE" }), _jsx(Button, { onClick: async () => setRecords(await downloadRecords(deep)), children: "DOWNLOAD RECORDS" }), records?.map((r) => (_jsx("audio", { controls: true, src: `data:${r.mimetype};base64,${r.sound}` }, Math.random().toString())))] }));
}
